package it.inaf.oats.ia2.tapschemamanager.businesslayer;

import it.inaf.oats.ia2.tapschemamanager.datalayer.ColumnEntity;
import it.inaf.oats.ia2.tapschemamanager.datalayer.TapSchemaHandler;

/**
 *
 * @author Sonia Zorba <zorba at oats.inaf.it>
 */
public class Column extends EntityWrapper<ColumnEntity> {

    public static final String UTYPE = "utype";
    public static final String UCD = "ucd";
    public static final String UNIT = "unit";
    public static final String DESCRIPTION = "description";
    public static final String STD = "std";
    public static final String PRINCIPAL = "principal";

    private final String datatype;
    private final int size;
    private final boolean primaryKey;
    private final boolean indexed;

    private final String foreignKeyReference;

    private boolean hidden;

    public Column(TapSchemaHandler tapSchemaHandler, ColumnEntity columnEntity, boolean primaryKey) {
        super(columnEntity, UTYPE, UCD, UNIT, DESCRIPTION, STD, PRINCIPAL);
        hidden = true;
        this.primaryKey = primaryKey;
        this.datatype = columnEntity.getDatatype();
        this.size = columnEntity.getSize();
        this.indexed = columnEntity.getIndexed() == 1;

        addValue(UTYPE, columnEntity.getUtype());
        addValue(UCD, columnEntity.getUcd());
        addValue(UNIT, columnEntity.getUnit());
        addValue(DESCRIPTION, columnEntity.getDescription());
        addValue(STD, columnEntity.getStd() + "");
        addValue(PRINCIPAL, columnEntity.getPrincipal() + "");

        String tableName = columnEntity.getFullTableName();
        String schemaName = columnEntity.getTable().getSchemaName();
        foreignKeyReference = tapSchemaHandler.getForeignKeyReference(schemaName, tableName, columnEntity.getName());
    }

    @Override
    protected void afterSetValue(String key, String value) {
        ColumnEntity columnEntity = getEntity();
        if (key.equals(UTYPE)) {
            columnEntity.setUtype(value);
        } else if (key.equals(UCD)) {
            columnEntity.setUcd(value);
        } else if (key.equals(UNIT)) {
            columnEntity.setUnit(value);
        } else if (key.equals(DESCRIPTION)) {
            columnEntity.setDescription(value);
        } else if (key.equals(STD)) {
            columnEntity.setStd(Integer.parseInt(value));
        } else if (key.equals(PRINCIPAL)) {
            columnEntity.setPrincipal(Integer.parseInt(value));
        }
    }

    public boolean isHidden() {
        return hidden;
    }

    public void setHidden(boolean hidden) {
        this.hidden = hidden;
        if (hidden) {
            undoChanges();
        }
    }

    public String getDatatype() {
        return datatype;
    }

    public int getSize() {
        return size;
    }

    public boolean isPrimaryKey() {
        return primaryKey;
    }

    public String getForeignKey() {
        return foreignKeyReference;
    }

    public boolean isIndexed() {
        return indexed;
    }
}
